@@ -8,6 +8,8 @@
 package Debian::Debhelper::Buildsystem::pybuild;
 
 use strict;
+use Cwd;
+use File::Spec;
 use Dpkg::Control;
 use Dpkg::Changelog::Debian;
 use Debian::Debhelper::Dh_Lib qw(%dh error doit);
@@ -115,7 +117,7 @@ sub pybuild_commands {
 	# Pass dh's destdir, if it's not the default value
 	if ($step eq 'install') {
 		my $destdir = shift(@options);
-		if ($destdir ne "debian/tmp") {
+		if (File::Spec->rel2abs($destdir, getcwd()) ne File::Spec->rel2abs("debian/tmp", getcwd())) {
 			push @options, "--dest-dir=$destdir";
 		}
 	}
